@@ -69,7 +69,7 @@ class Worker(multiprocessing.Process):
             log.warn('error unlocking log, continuing anyway '
                      'since lock will timeout. Traceback:', exc_info=True)
 
-    def set_bound(self, key, marker, retries, timestamp, type_=None):
+    def set_bound(self, key, marker, retries, type_=None):
         # api doesn't allow setting a bound with a blank marker
         if marker:
             if type_ is None:
@@ -81,7 +81,7 @@ class Worker(multiprocessing.Process):
                 client.set_worker_bound(self.dest_conn,
                                         type_,
                                         marker,
-                                        timestamp,
+                                        DEFAULT_TIME,
                                         self.daemon_id,
                                         key,
                                         data=data)
@@ -218,7 +218,7 @@ class DataWorker(Worker):
         self.object_sync_timeout = kwargs.get('object_sync_timeout', 60 * 60 * 60)
         self.daemon_id = kwargs['daemon_id']
 
-    def sync_object(self, bucket, bucket_id, obj):
+    def sync_object(self, bucket, obj):
         log.debug('syncing object %s/%s', bucket, obj.name)
         self.op_id += 1
         local_op_id = self.local_lock_id + ':' +  str(self.op_id)
@@ -226,9 +226,7 @@ class DataWorker(Worker):
 
         try:
             until = time.time() + self.object_sync_timeout
-            client.sync_object_intra_region(self.dest_conn, bucket,
-                                            bucket_id,
-                                            obj,
+            client.sync_object_intra_region(self.dest_conn, bucket, obj,
                                             self.src.zone.name,
                                             self.daemon_id,
                                             local_op_id)
@@ -238,8 +236,6 @@ class DataWorker(Worker):
                       bucket, obj.name)
             try:
                 client.delete_object(self.dest_conn, bucket, obj)
-                client.remove_op_state(self.dest_conn, self.daemon_id,
-                                       local_op_id, bucket, obj)
             except NotFound:
                 # Since we were trying to delete the object, just return
                 return False
@@ -268,22 +264,6 @@ class DataWorker(Worker):
 
         return True
 
-    def delete_object(self, bucket, obj, mtime):
-        log.debug('syncing object %s/%s', bucket, obj.name)
-        self.op_id += 1
-        local_op_id = self.local_lock_id + ':' +  str(self.op_id)
-
-        try:
-            client.delete_object(self.dest_conn, bucket, obj, mtime)
-        except NotFound:
-            log.debug('object "%s/%s" not found', bucket, obj.name)
-        except Exception as error:
-            msg = 'encountered an error during sync'
-            dev_log.warn(msg, exc_info=True)
-            log.warning('%s: %s' % (msg, error))
-
-        return True
-
     def wait_for_object(self, bucket, obj, until, local_op_id):
         while time.time() < until:
             try:
@@ -312,11 +292,6 @@ class DataWorker(Worker):
         metadata = client.get_metadata(self.src_conn, 'bucket', bucket)
         return bucket + ':' + metadata['data']['bucket']['bucket_id']
 
-    def get_bucket_metadata(self, bucket):
-        bucket_instance = self.get_bucket_instance(bucket)
-        metadata = client.get_metadata(self.src_conn, 'bucket.instance', bucket_instance)
-        return bucket_instance, metadata
-
     def get_bucket(self, bucket_instance):
         return bucket_instance.split(':', 1)[0]
 
@@ -386,7 +361,7 @@ class DataWorkerIncremental(IncrementalMixin, DataWorker):
         bucket = self.get_bucket(instance)
         new_retries = self.sync_bucket(bucket, objects.union(retries))
 
-        result = self.set_bound(instance, max_marker, new_retries, timestamp,
+        result = self.set_bound(instance, max_marker, new_retries,
                                 'bucket-index')
         if new_retries:
             result = RESULT_ERROR
@@ -445,7 +420,7 @@ class DataWorkerFull(DataWorker):
             objects = client.list_objects_in_bucket(self.src_conn, bucket)
             retries = self.sync_bucket(bucket, objects)
 
-            result = self.set_bound(instance, marker, retries, DEFAULT_TIME, 'bucket-index')
+            result = self.set_bound(instance, marker, retries, 'bucket-index')
             return not retries and result == RESULT_SUCCESS
         except BucketEmpty:
             log.debug('no objects in bucket %s', bucket)
